### Name: BactRoom
### Title: Bacteria Virus in Plant Sap by Room
### Aliases: BactRoom
### Keywords: datasets

### ** Examples

data( BactRoom )
BactRoom$trt <- factor( BactRoom$trt )
BactRoom$code <- factor( BactRoom$code )
contrasts( BactRoom$temp ) <- contr.sum
contrasts( BactRoom$bact ) <- contr.sum
contrasts( BactRoom$inoc ) <- contr.sum

BactRoom.badd <- aov( bill ~ temp + bact + inoc, BactRoom )
summary( BactRoom.badd )

BactRoom.full <- aov( bill ~ temp * bact, BactRoom )
lsmean( BactRoom.full )
summary( BactRoom.full )

BactRoom.bill <- aov( bill ~ temp * bact * inoc, BactRoom )
lsmean( BactRoom.bill )

# C:8.1 Bacteria Interaction Plots

BactRoom.trt <- aov( bill ~ trt * inoc, BactRoom )
int.plot( BactRoom.trt, split = c(1,1,2,1), more = TRUE,
  bar.plot="none",
  xlab="(a) treatment by inoc", ylab="bill length (mm)",
  main = "Figure C:8.1a Wrong Way" )

int.plot( BactRoom.bill, bar.plot="none", split = c(2,1,2,1),
  xlab="(b) temp by bact", ylab="", lty = c(1,1,2,2),
  main = "Figure C:8.1b Right Way", white = FALSE )

# C:8.2 Bacteria Two Factor Interaction Plots

lsd.plot( BactRoom.full,
  xlab="(a) interaction plot", ylab="bill length (mm)",
  ypos=40, lty = 1,
  main = "Figure C:8.2a Interaction with LSD",
  split = c(1,1,2,1), more = TRUE )

margin.plot( BactRoom.full, ylim=range( BactRoom$bill ),
  effects=TRUE, xlab="(b) margin plot", ylab="",
  ypos=40, lty = 1, split = c(2,1,2,1),
  main = "Figure C:8.2b Margin Plot with LSD" )

# C:8.3 Bacteria Three Factor Interaction Plots

Bacteria.ylab <- c("","bill length (mm)")
Bacteria.xlab <- c("(a)","(b)")
Bacteria.main = c( "Figure C:8.3", "Three-Factor Interactions" )
Bacteria.inoc = levels( BactRoom$inoc )
for ( i in 1:2) {
  tmpdata = BactRoom[ BactRoom$inoc == Bacteria.inoc[i], ]
  print( xyplot( bill ~ temp, tmpdata, groups = bact, type="b",
    xlab = paste( Bacteria.xlab[i], Bacteria.inoc[i], "inoc" ),
    ylab = Bacteria.ylab[i],
    main = Bacteria.main[i] ),
    split = c(i,1,2,1), more = ( i == 1 ))
}
rm( Bacteria.xlab, Bacteria.ylab, Bacteria.main, Bacteria.inoc, tmpdata )

# C: Bacteria Half-Normal and Effect Plots
# order -- temp:bact:inoc temp:bact bact:inoc temp:inoc inoc bact temp

BactRoom.coef = sort( abs( coef( BactRoom.bill )[-1] ))
BactRoom.coef = BactRoom.coef * sqrt( length( BactRoom.coef ))

qhalfnorm = function(p)qnorm((1+p)/2)
qhalfquant <- qhalfnorm(ppoints(length(BactRoom.coef)))
print( qqmath( ~ BactRoom.coef, distribution = qhalfnorm,
  prepanel = prepanel.qqmathline,
  xlim = range(qhalfquant) + c(-.2,.2), ## make room for text
  panel = function(x, ...) {
    panel.qqmathline(x, distribution = qhalfnorm, lty = 2 )
    panel.text(qhalfquant, x, names(BactRoom.coef))
  },
  xlab = "(a) half-normal quantiles", ylab = "effects",
  main = "Figure C:8.4a Half-Normal Plot" ))

effect.plot( BactRoom.bill, xlim = c(.5,7.5), xaxt = "n",
   xlab = "(b) terms", ylab = "MS adjusted effects" )
title( "Figure C:8.4b Effects Plot" )
axis( 1, seq(1,7,by=2), c("T","I","IT","BIT") )
axis( 1, seq(2,6,by=2), c("B","BT","BI") )



