### Name: Diet
### Title: Diet Effect on Dry Matter Intake
### Aliases: Diet
### Keywords: datasets

### ** Examples

data( Diet )

Diet$trt <- factor(Diet$trt)
Diet$block <- factor(Diet$block)
#
# ordinary anova
Diet.fit <- aov(dmi ~ trt, Diet)

# ancova with covar = first 3 weeks dmi
Diet.cov <- lm(dmi ~ covar + trt, Diet, na.action=na.omit)

# ancova with blocking and weighting by number of weeks on trial
Diet.blk <- lm(dmi ~ covar + block + trt, Diet,
   weights=Diet$weeks, na.action=na.omit)

# Figure F17.2: Diet Adjusted for Initial Capacity
## regression lines in following plot are not parallel
Diet = Diet[!is.na(Diet$covar), ]
Diet$pred = predict(Diet.cov)
trellis.par.set(theme=col.whitebg())
print(xyplot(dmi ~ covar, Diet, groups = trt, type = "p",
  pch = levels(Diet$trt), cex = 1.5,
  col = 1 + as.numeric(levels(Diet$trt)),
  panel = function(x,y,...) {
    panel.superpose(x,y,...)
    pred = predict(Diet.cov)
    for(i in levels(Diet$trt)) {
      ii = Diet$trt == i
      i = as.numeric(i)
      panel.lines(Diet$covar[ii], Diet$pred[ii],
        lty = i, col = i + 1)
    }
    ## SD bar
    lsd.bar(Diet.cov, xpos = 24, ypos=20, cap = "SD")
  },
  xlab = "covariate = first 3 weeks",
  ylab = "dry matter intake (dmi)",
  main = "Figure F:17.2 Diet Adjusted for Initial Capacity"))
data.frame(se.bar(26, 20, std.dev(Diet.cov), cap = "SD"))



