### Name: Growth
### Title: Growth Medium for Plant Tissue
### Aliases: Growth
### Keywords: datasets

### ** Examples

data( Growth )

#Growth <- Growth[,c("trt","advplt")]
# drop the added BHTA control ( trt = 20 )
Growth <- Growth[ Growth$trt != 20, ]
Growth$logadvplt <- log10(1+Growth$advplt)
 
Growth$trt <- factor(Growth$trt)
Growth$BA <- ordered(Growth$BA)
Growth$TDZ <- ordered(Growth$TDZ)
Growth <- Growth[!is.na(Growth$advplt),]

sample.size( Growth$BA, Growth$TDZ )

Growth.zero <- Growth[Growth$advplt>0,]

Growth.fit <- lm(logadvplt~trt,Growth)
Growth.zero.fit <- lm(logadvplt~trt,Growth.zero)

Growth.full <- aov( logadvplt ~ BA * TDZ, Growth )
Growth.add <- aov( logadvplt ~ BA + TDZ, Growth )

# D:11.1 Growth interaction plots with a missing cell

int.plot( Growth.full, xpos = 2.5, ypos = .425,
  xaxt = "n", xlab = "(a) BA by TDZ", ylab = "",
  main = "Figure D:11.1",
  more = TRUE, split = c(1,1,2,1) )
int.plot( Growth.full, fac = c("TDZ","BA"),
  xpos = 3.25, ypos = .425, xaxt = "n",
  xlab = "log(1 + advplt)", ylab = "(b) TDZ by BA",
  main = "Growth Interaction",
  split = c(2,1,2,1) )

# E:13.2 Growth residual plots with zeros
tmpdata = data.frame( x = jitter( predict( Growth.fit )),
  y = jitter( resid( Growth.fit )), group = Growth$code )
print( xyplot( y ~ x, tmpdata, groups = group,
  panel = function(...) {
    panel.superpose(...)
    panel.abline( h = 0, lty = 2 )
    panel.abline( h = c(-1,1) * std.dev( Growth.fit ), lty = 3 )
    panel.abline( 0, -1 )
  },
  xlab = "(a) mean with zeroes", ylab = "residuals",
  main = "Figure E:13.2" ),
  more = TRUE, split = c(1,1,2,1) )

tmpdata = data.frame( x = jitter( predict( Growth.zero.fit )),
  y = jitter( resid( Growth.zero.fit )), group = Growth.zero$code )
print( xyplot( y ~ x, tmpdata, groups = group,
  panel = function(...) {
    panel.superpose(...)
    panel.abline( h = 0, lty = 2 )
    panel.abline( h = c(-1,1) * std.dev( Growth.zero.fit ), lty = 3 )
    panel.abline( 0, -1 )
  },
  xlab = "(b) mean without zeroes", ylab = "",
  main = "Growth Residuals" ), 
  split = c(2,1,2,1) )



