### Name: Oocyte
### Title: Oocyte Development
### Aliases: Oocyte
### Keywords: datasets

### ** Examples

data( Oocyte )

Oocyte$asper <- 100 * asin( sqrt( Oocyte$gv / Oocyte$toocytes ) )

Oocyte$h89 <- ordered( Oocyte$h89 )
Oocyte$fors <- ordered( Oocyte$fors )
Oocyte$date <- ordered( Oocyte$date )

sample.size( Oocyte$h89, Oocyte$fors )

cat( "Type I sums of squares:\n" )
Oocyte.fit <- aov( asper ~ h89 * fors, Oocyte )
summary( Oocyte.fit )
summary( aov( asper ~ fors * h89, Oocyte))
cat( "Type III sums of squares:\n" )
drop1( Oocyte.fit, formula( Oocyte.fit ), test = "F" )

cat( "Additive model:\n" )
Oocyte.afit <- aov( asper ~ h89 + fors, Oocyte )
cat( "Type II sums of squares:\n" )
drop1( Oocyte.afit, formula( Oocyte.afit ), test = "F" )

# D:10.1 Oocyte additive and interactive models

lsd.plot( Oocyte.afit, factors = c("fors","h89"),
  xlab = "(a) additive fit", ylab = "fors",
  more = TRUE, split = c(1,1,2,2) )
margin.plot( Oocyte.afit, factors = c("fors","h89"),
  xlab = "(b) additive margin", ylab = "",
  more = TRUE, split = c(2,1,2,2) )
lsd.plot( Oocyte.fit, factors = c("fors","h89"),
  xlab = "(c) interactive fit", ylab = "fors",
  more = TRUE, split = c(1,2,2,2) )
margin.plot( Oocyte.fit, factors = c("fors","h89"),
   xlab = "(d) interactive margin", ylab = "",
  split = c(2,2,2,2) )

# D:10.2 Oocyte Effects Plot
effect.plot( Oocyte.fit,
  main = "Figure D:10.2 Oocyte Effects Plot" )

cat( "Cautionary tale on Type III sums of squares\n",
   "Be sure to have sum to zero contrasts!\n" )
# first alter contrasts for H89
contrasts( Oocyte$h89 )
contrasts( Oocyte$h89 ) <- contr.treatment
contrasts( Oocyte$h89 )
Oocyte.trt <- aov( asper ~ h89 * fors, Oocyte )
drop1( Oocyte.trt, formula( Oocyte.trt ), test = "F" )

# now alter contrasts for forskolin
contrasts( Oocyte$fors )
contrasts( Oocyte$fors ) <- contr.treatment
contrasts( Oocyte$fors )
Oocyte.trt <- aov( asper ~ h89 * fors, Oocyte)
drop1( Oocyte.trt, formula( Oocyte.trt ), test = "F" )

# resetting contrasts for your sanity
contrasts( Oocyte$h89 ) <- contr.poly
contrasts( Oocyte$fors ) <- contr.poly



