### Name: Tree
### Title: Tree Weed Suppression over Time
### Aliases: Tree TreeAve
### Keywords: datasets

### ** Examples

# Analysis Averaged over Time
data( TreeAve )
# soil is automatically a factor() since it has characters
TreeAve.aov <- aov( score ~ soil, TreeAve)
summary( TreeAve.aov )
#plot( TreeAve.aov )
boxplot( split( TreeAve$score, TreeAve$soil))

# Analysis over Time
data( Tree )
Tree <- Tree[ Tree$acc == "notauto", ]
Tree$acc <- NULL
Tree$type <- factor( !is.na( match( Tree$soil,
   c("dtac2","nc11004","ne-332","nm-6") )))
Tree$reps <- factor( Tree$reps )

Trees <- Tree[ rep( seq( nrow( Tree ) ), 6 ), c("soil","reps","type") ]
Trees$date <- ordered( rep( 1:6, rep( nrow( Tree ), 6 ) ) )
Trees$score <- unlist( Tree[ , paste( "score", 1:6, sep="" ) ] )
row.names(Trees) <- interaction( Trees[, c("soil","reps","date") ] )

Trees.soil <- aov(score ~ soil * date + Error(reps/soil), Trees )
# combined (sort of)
Trees.all <- aov( score ~ soil * date, Trees )

# Figure I:25.1 Tree scores over time by soil type

Tree.lsm <- lsmean( Trees.all, factors = c("soil","date") )
Tree.lsm$type <- factor( !is.na( match( Tree.lsm$soil,
   c("dtac2","nc11004","ne-332","nm-6") ) ) )

Tree.lsm <- split( Tree.lsm, Tree.lsm$type )
# following values are SE for means taken for SAS output
Tree.lsm[[1]]$se <- rep( .84086871, nrow( Tree.lsm[[1]] ) )
Tree.lsm[[2]]$se <- rep( .63433993, nrow( Tree.lsm[[2]] ) )

Tree.data <- split( Trees, Trees$type )
Tree.xlab <- c("(b) control","(a) Tree")
Tree.ylab <- c("","score means")
Tree.ylim = range( pretty( c( Tree.lsm[[1]]$pred, Tree.lsm[[2]]$pred )))

for( i in 2:1 ) { # "FALSE" comes before "TRUE"
   int.plot( Trees.all, Tree.data[[i]], c("date","soil"),
      Tree.lsm[[i]], bar.plot = "none", ylim = Tree.ylim,
      panelf = function(...) {
        se.bar( 4.5, 2, Tree.lsm[[i]]$se[1] )
        Tree.tmp <- Tree.lsm[[i]][Tree.lsm[[i]]$date==6,]
        panel.text( rep( 4.5, nrow( Tree.tmp ) ),
          0.25 + Tree.tmp$pred,
          as.character( Tree.tmp$soil ), adj = 0 )
      },
      xlab = paste( Tree.xlab[i], "soils by date" ),
      ylab = Tree.ylab[i],
      more = (i == 2), split = c(3-i,1,2,1) )
}
rm( Tree.data, Tree.xlab, Tree.ylab, Tree.lsm )

# Figure I:25.2 Tree whole plot experimental units

Tree.xlab <- c("(b) control","(a) Tree")
Tree.ylab <- c("","soil sample means")

library(lme4)
Trees.lme <- lmer(score ~ soil * date + (1|reps:soil), data = Trees )
VarCorr( Trees.lme )
anova( Trees.lme )

## Not run: 
##D # projections (*** CAUTION: SLOW ***)
##D # This works for now in Splus but not in R!
##D Trees.type <- aov(score ~ type/soil * date +
##D    Error(reps %in% soil %in% type), Trees, proj = TRUE )
##D Trees.proj <- proj ( Trees.type )
##D # whole plot
##D Trees.wp <- nested( Trees.proj, Trees, c("type","soil","reps"), "score",
##D    c(1,2), Trees.ref )
##D Trees.wpaov <- aov( score ~ soil, Trees.wp )
##D Tree.grmean <- lsmean( Trees.wpaov, fac = NULL )$pred
##D Tree.lsm <- lsmean( Trees.wpaov, factors = "soil" )
##D Tree.lsm$type <- factor( !is.na( match( Tree.lsm$soil,
##D    c("dtac2","nc11004","ne-332","nm-6") ) ) )
##D Tree.lsm <- split( Tree.lsm, Tree.lsm$type )
##D Tree.data <- split( Trees.wp, Trees.wp$type )
##D for ( i in 2:1 ) { # "FALSE" comes before "TRUE"
##D    Tree.lsm[[i]]$rank <- rank( -Tree.lsm[[i]]$pred )
##D    # have to be careful about levels of soil in type subsets
##D    Tree.data[[i]]$soil <- factor( Tree.data[[i]]$soil )
##D    attach( Tree.data[[i]] )
##D    names( Tree.lsm[[i]]$rank ) <- unique( soil )
##D    plot( jitter( Tree.lsm[[i]]$rank[soil] ), score, xaxt = "n",
##D       ylim = range( Trees.wp$score ),
##D       xlab = paste( Tree.xlab[i], "soil sample means" ),
##D       ylab = Tree.ylab[i] )
##D    detach()
##D    axis( 1, Tree.lsm[[i]]$rank, row.names( Tree.lsm[[i]] ) )
##D    abline( h = Tree.grmean, lty = 3 )
##D }
##D axis( 1, Tree.lsm[[1]]["grnhous","rank"], "grnhous" )
##D rm( Tree.data, Tree.xlab, Tree.ylab, Tree.grmean, Tree.lsm )
##D 
##D # Figure I:25.3 Tree repeated measures within soil sample
##D 
##D Trees.ref <- data.frame( Reference = c( Trees.proj[[1]] ))
##D for (i in names( Trees.proj )[-1])
##D    Trees.ref[[i]] <- apply( Trees.proj[[i]], 1, sum )
##D 
##D # split plot
##D Trees.sp <- nested( Trees.proj, Trees, c("type","soil","reps","date"),
##D    "score", c(1,3), Trees.ref )
##D 
##D Trees.spaov <- aov( score ~ reps*soil + date + date:soil, Trees.sp )
##D 
##D # split plot with time trend removed
##D Trees.sp$res <- resid( aov( score ~ reps*soil + date, Trees.sp ) ) +
##D    lsmean( Trees.spaov, fac=NULL )$pred
##D 
##D Trees.spres <- aov( res ~ reps*soil + date + date:soil, Trees.sp )
##D 
##D Tree.lsm <- lsmean( Trees.spaov, factors = c("soil","date") )
##D Tree.lsm$type <- factor( !is.na( match( Tree.lsm$soil,
##D    c("dtac2","nc11004","ne-332","nm-6") ) ) )
##D 
##D Tree.lsm <- split( Tree.lsm, Tree.lsm$type )
##D # following values are SE for contrasts taken from SAS output
##D Tree.lsm[[1]]$se <- rep( .42023472 / sqrt( 2 ), nrow( Tree.lsm[[1]] ) )
##D Tree.lsm[[2]]$se <- rep( .35818796 / sqrt( 2 ), nrow( Tree.lsm[[2]] ) )
##D 
##D Tree.data <- split( Trees.sp, Trees.sp$type )
##D Tree.xlab <- c("(b) control","(a) Tree")
##D Tree.ylab <- c("","pure split plot score")
##D for ( i in 2:1 ) { # "FALSE" comes before "TRUE"
##D    lsd.plot( Trees.spaov, Tree.data[[i]], c("date","soil"),
##D       Tree.lsm[[i]],
##D       xpos = 6, xlim = c(1,7.7), ylim = range( Tree.lsm$pred ),
##D       xaxt = "n", xlab = paste( Tree.xlab[i], "soils by date" ),
##D       ylab = Tree.ylab[i] )
##D    axis(1,1:6)
##D    Tree.tmp <- Tree.lsm[[i]][Tree.lsm[[i]]$date==6,]
##D    text( rep( 6.2, nrow( Tree.tmp ) ),
##D       uncollide( Tree.tmp$pred, c(.7,1.6)[i] ),
##D       as.character( Tree.tmp$soil ), adj = 0 )
##D }
##D rm( Tree.data, Tree.xlab, Tree.ylab, Tree.lsm, Tree.tmp )
##D 
##D # Figure I:25.4 Tree detrended repeated measures
##D Tree.lsm <- lsmean( Trees.spres, factors = c("soil","date") )
##D Tree.lsm$type <- factor( !is.na( match( Tree.lsm$soil,
##D    c("dtac2","nc11004","ne-332","nm-6") ) ) )
##D 
##D Tree.lsm <- split( Tree.lsm, Tree.lsm$type )
##D # following values are SE for contrasts take for SAS output
##D Tree.lsm[[1]]$se <- rep( .42023472 / sqrt( 2 ), nrow( Tree.lsm[[1]] ) )
##D Tree.lsm[[2]]$se <- rep( .35818796 / sqrt( 2 ), nrow( Tree.lsm[[2]] ) )
##D 
##D Tree.data <- split( Trees.sp, Trees.sp$type )
##D Tree.xlab <- c("(b) control","(a) Tree")
##D Tree.ylab <- c("","pure split plot score")
##D for ( i in 2:1 ) { # "FALSE" comes before "TRUE"
##D    lsd.plot( Trees.spres, Tree.data[[i]], c("date","soil"), Tree.lsm[[i]],
##D       xpos = 4.5, ypos = 4.25,
##D       xlim = c(1,7.7), ylim = range( Tree.lsm$pred ),
##D       xaxt = "n",
##D       xlab = paste( Tree.xlab[i], "soils by date" ),
##D       ylab = Tree.ylab[i] )
##D    axis(1,1:6)
##D    Tree.tmp <- Tree.lsm[[i]][ Tree.lsm[[i]]$date == 6, ]
##D    text( rep( 6.2, nrow( Tree.tmp ) ),
##D       uncollide( Tree.tmp$pred, c(.3,.6)[i] ),
##D       as.character( Tree.tmp$soil ), adj = 0 )
##D }
##D rm( Tree.data, Tree.xlab, Tree.ylab, Tree.lsm, Tree.tmp )
##D 
##D # Figure I:26.1 Tree partial correlations over time
##D Tree.tmpc <- length( unique( Trees.sp$date ))
##D Tree.tmpr <- nrow( Trees.sp ) / Tree.tmpc
##D Tree.tmp <- matrix( resid( Trees.spaov ), Tree.tmpr, Tree.tmpc )
##D Tree.tmpid <- c("C","T")[ codes( Trees.sp$type[1:Tree.tmpr] ) ]
##D 
##D splom( Tree.tmp, varnames = as.character( unique( Trees.sp$date )),
##D    groups = Tree.tmpid )
##D rm( Tree.tmp, Tree.tmpr, Tree.tmpc )
## End(Not run)



